import { API as ParentAPI } from '../../../bridge';
import type { Region } from '../../../bridge';
import type { ListEventsRequest, ListEventsResponse, ListProductsRequest, ListProductsResponse } from './types.gen';
/**
 * Audit Trail API.
 *
 * This API allows you to ensure accountability and security by recording events
 * and changes performed within your Scaleway Organization.
 */
export declare class API extends ParentAPI {
    /** Lists the available regions of the API. */
    static readonly LOCALITIES: Region[];
    /**
     * List events. Retrieve the list of Audit Trail events for a Scaleway
     * Organization and/or Project. You must specify the `organization_id` and
     * optionally, the `project_id`.
     *
     * @param request - The request {@link ListEventsRequest}
     * @returns A Promise of ListEventsResponse
     */
    listEvents: (request?: Readonly<ListEventsRequest>) => Promise<ListEventsResponse>;
    /**
     * Retrieve the list of Scaleway resources for which you have Audit Trail
     * events.
     *
     * @param request - The request {@link ListProductsRequest}
     * @returns A Promise of ListProductsResponse
     */
    listProducts: (request?: Readonly<ListProductsRequest>) => Promise<ListProductsResponse>;
}
