"use strict";
Object.defineProperty(exports, Symbol.toStringTag, { value: "Module" });
const json = require("../../../helpers/json.cjs");
const marshalling = require("../../../helpers/marshalling.cjs");
require("../../../vendor/base64/index.cjs");
const unmarshalLink = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'Link' failed as data isn't a dictionary.`
    );
  }
  return {
    bandwidthMbps: data.bandwidth_mbps,
    bgpV4Status: data.bgp_v4_status,
    bgpV6Status: data.bgp_v6_status,
    createdAt: marshalling.unmarshalDate(data.created_at),
    disapprovedReason: data.disapproved_reason,
    enableRoutePropagation: data.enable_route_propagation,
    id: data.id,
    name: data.name,
    organizationId: data.organization_id,
    pairingKey: data.pairing_key,
    partnerId: data.partner_id,
    popId: data.pop_id,
    projectId: data.project_id,
    region: data.region,
    routingPolicyId: data.routing_policy_id,
    status: data.status,
    tags: data.tags,
    updatedAt: marshalling.unmarshalDate(data.updated_at),
    vpcId: data.vpc_id
  };
};
const unmarshalPartner = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'Partner' failed as data isn't a dictionary.`
    );
  }
  return {
    contactEmail: data.contact_email,
    createdAt: marshalling.unmarshalDate(data.created_at),
    id: data.id,
    logoUrl: data.logo_url,
    name: data.name,
    portalUrl: data.portal_url,
    updatedAt: marshalling.unmarshalDate(data.updated_at)
  };
};
const unmarshalPop = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'Pop' failed as data isn't a dictionary.`
    );
  }
  return {
    address: data.address,
    availableLinkBandwidthsMbps: data.available_link_bandwidths_mbps,
    city: data.city,
    hostingProviderName: data.hosting_provider_name,
    id: data.id,
    logoUrl: data.logo_url,
    name: data.name,
    region: data.region
  };
};
const unmarshalRoutingPolicy = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'RoutingPolicy' failed as data isn't a dictionary.`
    );
  }
  return {
    createdAt: marshalling.unmarshalDate(data.created_at),
    id: data.id,
    name: data.name,
    organizationId: data.organization_id,
    prefixFilterIn: data.prefix_filter_in,
    prefixFilterOut: data.prefix_filter_out,
    projectId: data.project_id,
    region: data.region,
    tags: data.tags,
    updatedAt: marshalling.unmarshalDate(data.updated_at)
  };
};
const unmarshalListLinksResponse = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'ListLinksResponse' failed as data isn't a dictionary.`
    );
  }
  return {
    links: marshalling.unmarshalArrayOfObject(data.links, unmarshalLink),
    totalCount: data.total_count
  };
};
const unmarshalListPartnersResponse = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'ListPartnersResponse' failed as data isn't a dictionary.`
    );
  }
  return {
    partners: marshalling.unmarshalArrayOfObject(data.partners, unmarshalPartner),
    totalCount: data.total_count
  };
};
const unmarshalListPopsResponse = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'ListPopsResponse' failed as data isn't a dictionary.`
    );
  }
  return {
    pops: marshalling.unmarshalArrayOfObject(data.pops, unmarshalPop),
    totalCount: data.total_count
  };
};
const unmarshalListRoutingPoliciesResponse = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'ListRoutingPoliciesResponse' failed as data isn't a dictionary.`
    );
  }
  return {
    routingPolicies: marshalling.unmarshalArrayOfObject(
      data.routing_policies,
      unmarshalRoutingPolicy
    ),
    totalCount: data.total_count
  };
};
const marshalAttachRoutingPolicyRequest = (request, defaults) => ({
  routing_policy_id: request.routingPolicyId
});
const marshalAttachVpcRequest = (request, defaults) => ({
  vpc_id: request.vpcId
});
const marshalCreateLinkRequest = (request, defaults) => ({
  bandwidth_mbps: request.bandwidthMbps,
  name: request.name,
  pop_id: request.popId,
  project_id: request.projectId ?? defaults.defaultProjectId,
  tags: request.tags,
  ...marshalling.resolveOneOf([
    { param: "dedicated", value: request.dedicated },
    { param: "port_id", value: request.portId },
    { param: "partner_id", value: request.partnerId }
  ])
});
const marshalCreateRoutingPolicyRequest = (request, defaults) => ({
  name: request.name,
  prefix_filter_in: request.prefixFilterIn,
  prefix_filter_out: request.prefixFilterOut,
  project_id: request.projectId ?? defaults.defaultProjectId,
  tags: request.tags
});
const marshalUpdateLinkRequest = (request, defaults) => ({
  name: request.name,
  tags: request.tags
});
const marshalUpdateRoutingPolicyRequest = (request, defaults) => ({
  name: request.name,
  prefix_filter_in: request.prefixFilterIn,
  prefix_filter_out: request.prefixFilterOut,
  tags: request.tags
});
exports.marshalAttachRoutingPolicyRequest = marshalAttachRoutingPolicyRequest;
exports.marshalAttachVpcRequest = marshalAttachVpcRequest;
exports.marshalCreateLinkRequest = marshalCreateLinkRequest;
exports.marshalCreateRoutingPolicyRequest = marshalCreateRoutingPolicyRequest;
exports.marshalUpdateLinkRequest = marshalUpdateLinkRequest;
exports.marshalUpdateRoutingPolicyRequest = marshalUpdateRoutingPolicyRequest;
exports.unmarshalLink = unmarshalLink;
exports.unmarshalListLinksResponse = unmarshalListLinksResponse;
exports.unmarshalListPartnersResponse = unmarshalListPartnersResponse;
exports.unmarshalListPopsResponse = unmarshalListPopsResponse;
exports.unmarshalListRoutingPoliciesResponse = unmarshalListRoutingPoliciesResponse;
exports.unmarshalPartner = unmarshalPartner;
exports.unmarshalPop = unmarshalPop;
exports.unmarshalRoutingPolicy = unmarshalRoutingPolicy;
